@@ -7,15 +7,17 @@ import builtins
 import sys
 
 from IPython.core.displayhook import DisplayHook
+from jupyter_client.session import Session, extract_header
+from traitlets import Any, Dict, Instance
+
 from ipykernel.jsonutil import encode_images, json_clean
-from traitlets import Instance, Dict, Any
-from jupyter_client.session import extract_header, Session
 
 
 class ZMQDisplayHook:
     """A simple displayhook that publishes the object's repr over a ZeroMQ
     socket."""
-    topic = b'execute_result'
+
+    topic = b"execute_result"
 
     def __init__(self, session, pub_socket):
         self.session = session
@@ -33,11 +35,14 @@ class ZMQDisplayHook:
         builtins._ = obj
         sys.stdout.flush()
         sys.stderr.flush()
-        contents = {'execution_count': self.get_execution_count(),
-                    'data': {'text/plain': repr(obj)},
-                    'metadata': {}}
-        self.session.send(self.pub_socket, 'execute_result', contents,
-                          parent=self.parent_header, ident=self.topic)
+        contents = {
+            "execution_count": self.get_execution_count(),
+            "data": {"text/plain": repr(obj)},
+            "metadata": {},
+        }
+        self.session.send(
+            self.pub_socket, "execute_result", contents, parent=self.parent_header, ident=self.topic
+        )
 
     def set_parent(self, parent):
         self.parent_header = extract_header(parent)
@@ -47,7 +52,8 @@ class ZMQShellDisplayHook(DisplayHook):
     """A displayhook subclass that publishes data using ZeroMQ. This is intended
     to work with an InteractiveShell instance. It sends a dict of different
     representations of the object."""
-    topic=None
+
+    topic = None
 
     session = Instance(Session, allow_none=True)
     pub_socket = Any(allow_none=True)
@@ -58,23 +64,27 @@ class ZMQShellDisplayHook(DisplayHook):
         self.parent_header = extract_header(parent)
 
     def start_displayhook(self):
-        self.msg = self.session.msg('execute_result', {
-            'data': {},
-            'metadata': {},
-        }, parent=self.parent_header)
+        self.msg = self.session.msg(
+            "execute_result",
+            {
+                "data": {},
+                "metadata": {},
+            },
+            parent=self.parent_header,
+        )
 
     def write_output_prompt(self):
         """Write the output prompt."""
-        self.msg['content']['execution_count'] = self.prompt_count
+        self.msg["content"]["execution_count"] = self.prompt_count
 
     def write_format_data(self, format_dict, md_dict=None):
-        self.msg['content']['data'] = json_clean(encode_images(format_dict))
-        self.msg['content']['metadata'] = md_dict
+        self.msg["content"]["data"] = json_clean(encode_images(format_dict))
+        self.msg["content"]["metadata"] = md_dict
 
     def finish_displayhook(self):
         """Finish up all displayhook activities."""
         sys.stdout.flush()
         sys.stderr.flush()
-        if self.msg['content']['data']:
+        if self.msg["content"]["data"]:
             self.session.send(self.pub_socket, self.msg, ident=self.topic)
         self.msg = None
