@@ -19,35 +19,28 @@ import sys
 import warnings
 from threading import local
 
-from IPython.core.interactiveshell import (
-    InteractiveShell, InteractiveShellABC
-)
-from IPython.core import page
+from IPython.core import page, payloadpage
 from IPython.core.autocall import ZMQExitAutocall
 from IPython.core.displaypub import DisplayPublisher
 from IPython.core.error import UsageError
-from IPython.core.magics import MacroToEdit, CodeMagics
-from IPython.core.magic import magics_class, line_magic, Magics
-from IPython.core import payloadpage
+from IPython.core.interactiveshell import InteractiveShell, InteractiveShellABC
+from IPython.core.magic import Magics, line_magic, magics_class
+from IPython.core.magics import CodeMagics, MacroToEdit
 from IPython.core.usage import default_banner
-from IPython.display import display, Javascript
-from ipykernel import (
-    get_connection_file, get_connection_info, connect_qtconsole
-)
+from IPython.display import Javascript, display
 from IPython.utils import openpy
-from ipykernel.jsonutil import json_clean, encode_images
 from IPython.utils.process import arg_split, system
-from traitlets import (
-    Instance, Type, Dict, CBool, CBytes, Any, default, observe
-)
-from ipykernel.displayhook import ZMQShellDisplayHook
-
+from jupyter_client.session import Session, extract_header
 from jupyter_core.paths import jupyter_runtime_dir
-from jupyter_client.session import extract_header, Session
+from traitlets import Any, CBool, CBytes, Dict, Instance, Type, default, observe
 
-#-----------------------------------------------------------------------------
+from ipykernel import connect_qtconsole, get_connection_file, get_connection_info
+from ipykernel.displayhook import ZMQShellDisplayHook
+from ipykernel.jsonutil import encode_images, json_clean
+
+# -----------------------------------------------------------------------------
 # Functions and classes
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 
 
 class ZMQDisplayPublisher(DisplayPublisher):
@@ -56,11 +49,11 @@ class ZMQDisplayPublisher(DisplayPublisher):
     session = Instance(Session, allow_none=True)
     pub_socket = Any(allow_none=True)
     parent_header = Dict({})
-    topic = CBytes(b'display_data')
+    topic = CBytes(b"display_data")
 
     # thread_local:
     # An attribute used to ensure the correct output message
-    # is processed. See ipykernel Issue 113 for a discussion.
+    # is processed. See ipykernel Issue 113 for a discussion.
     _thread_local = Any()
 
     def set_parent(self, parent):
@@ -72,14 +65,14 @@ class ZMQDisplayPublisher(DisplayPublisher):
         sys.stdout.flush()
         sys.stderr.flush()
 
-    @default('_thread_local')
+    @default("_thread_local")
     def _default_thread_local(self):
         """Initialize our thread local storage"""
         return local()
 
     @property
     def _hooks(self):
-        if not hasattr(self._thread_local, 'hooks'):
+        if not hasattr(self._thread_local, "hooks"):
             # create new list for a new thread
             self._thread_local.hooks = []
         return self._thread_local.hooks
@@ -113,19 +106,16 @@ class ZMQDisplayPublisher(DisplayPublisher):
             transient = {}
         self._validate_data(data, metadata)
         content = {}
-        content['data'] = encode_images(data)
-        content['metadata'] = metadata
-        content['transient'] = transient
+        content["data"] = encode_images(data)
+        content["metadata"] = metadata
+        content["transient"] = transient
 
-        msg_type = 'update_display_data' if update else 'display_data'
+        msg_type = "update_display_data" if update else "display_data"
 
         # Use 2-stage process to send a message,
         # in order to put it through the transform
         # hooks before potentially sending.
-        msg = self.session.msg(
-            msg_type, json_clean(content),
-            parent=self.parent_header
-        )
+        msg = self.session.msg(msg_type, json_clean(content), parent=self.parent_header)
 
         # Each transform either returns a new
         # message or None. If None is returned,
@@ -136,7 +126,9 @@ class ZMQDisplayPublisher(DisplayPublisher):
                 return
 
         self.session.send(
-            self.pub_socket, msg, ident=self.topic,
+            self.pub_socket,
+            msg,
+            ident=self.topic,
         )
 
     def clear_output(self, wait=False):
@@ -153,8 +145,11 @@ class ZMQDisplayPublisher(DisplayPublisher):
         content = dict(wait=wait)
         self._flush_streams()
         self.session.send(
-            self.pub_socket, 'clear_output', content,
-            parent=self.parent_header, ident=self.topic,
+            self.pub_socket,
+            "clear_output",
+            content,
+            parent=self.parent_header,
+            ident=self.topic,
         )
 
     def register_hook(self, hook):
@@ -199,9 +194,9 @@ class ZMQDisplayPublisher(DisplayPublisher):
 
 @magics_class
 class KernelMagics(Magics):
-    #------------------------------------------------------------------------
+    # ------------------------------------------------------------------------
     # Magic overrides
-    #------------------------------------------------------------------------
+    # ------------------------------------------------------------------------
     # Once the base class stops inheriting from magic, this code needs to be
     # moved into a separate machinery as well.  For now, at least isolate here
     # the magics which this class needs to implement differently from the base
@@ -210,7 +205,7 @@ class KernelMagics(Magics):
     _find_edit_target = CodeMagics._find_edit_target
 
     @line_magic
-    def edit(self, parameter_s='', last_call=['','']):
+    def edit(self, parameter_s="", last_call=None):
         """Bring up an editor and execute the resulting code.
 
         Usage:
@@ -286,8 +281,8 @@ class KernelMagics(Magics):
 
         Note that %edit is also available through the alias %ed.
         """
-
-        opts,args = self.parse_options(parameter_s, 'prn:')
+        last_call = last_call or ["", ""]
+        opts, args = self.parse_options(parameter_s, "prn:")
 
         try:
             filename, lineno, _ = CodeMagics._find_edit_target(self.shell, args, opts, last_call)
@@ -300,11 +295,7 @@ class KernelMagics(Magics):
         # directory of client and kernel don't match
         filename = os.path.abspath(filename)
 
-        payload = {
-            'source' : 'edit_magic',
-            'filename' : filename,
-            'line_number' : lineno
-        }
+        payload = {"source": "edit_magic", "filename": filename, "line_number": lineno}
         self.shell.payload_manager.write_payload(payload)
 
     # A few magics that are adapted to the specifics of using pexpect and a
@@ -313,14 +304,14 @@ class KernelMagics(Magics):
     @line_magic
     def clear(self, arg_s):
         """Clear the terminal."""
-        if os.name == 'posix':
+        if os.name == "posix":
             self.shell.system("clear")
         else:
             self.shell.system("cls")
 
-    if os.name == 'nt':
+    if os.name == "nt":
         # This is the usual name in windows
-        cls = line_magic('cls')(clear)
+        cls = line_magic("cls")(clear)
 
     # Terminal pagers won't work over pexpect, but we do have our own pager
 
@@ -330,23 +321,23 @@ class KernelMagics(Magics):
 
         Files ending in .py are syntax-highlighted."""
         if not arg_s:
-            raise UsageError('Missing filename.')
+            raise UsageError("Missing filename.")
 
-        if arg_s.endswith('.py'):
+        if arg_s.endswith(".py"):
             cont = self.shell.pycolorize(openpy.read_py_file(arg_s, skip_encoding_cookie=False))
         else:
             cont = open(arg_s).read()
         page.page(cont)
 
-    more = line_magic('more')(less)
+    more = line_magic("more")(less)
 
     # Man calls a pager, so we also need to redefine it
-    if os.name == 'posix':
+    if os.name == "posix":
+
         @line_magic
         def man(self, arg_s):
             """Find the man page for the given command and display in pager."""
-            page.page(self.shell.getoutput('man %s | col -b' % arg_s,
-                                           split=False))
+            page.page(self.shell.getoutput("man %s | col -b" % arg_s, split=False))
 
     @line_magic
     def connect_info(self, arg_s):
@@ -373,9 +364,8 @@ class KernelMagics(Magics):
         if jupyter_runtime_dir() == os.path.dirname(connection_file):
             connection_file = os.path.basename(connection_file)
 
-
-        print (info + '\n')
-        print (
+        print(info + "\n")
+        print(
             f"Paste the above JSON into a file, and connect with:\n"
             f"    $> jupyter <app> --existing <file>\n"
             f"or, if you are local, you can connect with just:\n"
@@ -395,12 +385,13 @@ class KernelMagics(Magics):
 
         # %qtconsole should imply bind_kernel for engines:
         # FIXME: move to ipyparallel Kernel subclass
-        if 'ipyparallel' in sys.modules:
+        if "ipyparallel" in sys.modules:
             from ipyparallel import bind_kernel
+
             bind_kernel()
 
         try:
-            connect_qtconsole(argv=arg_split(arg_s, os.name=='posix'))
+            connect_qtconsole(argv=arg_split(arg_s, os.name == "posix"))
         except Exception as e:
             warnings.warn("Could not start qtconsole: %r" % e)
             return
@@ -423,8 +414,9 @@ class KernelMagics(Magics):
 
         # javascript wants milliseconds
         milliseconds = 1000 * interval
-        display(Javascript("IPython.notebook.set_autosave_interval(%i)" % milliseconds),
-            include=['application/javascript']
+        display(
+            Javascript("IPython.notebook.set_autosave_interval(%i)" % milliseconds),
+            include=["application/javascript"],
         )
         if interval:
             print("Autosaving every %i seconds" % interval)
@@ -441,7 +433,7 @@ class ZMQInteractiveShell(InteractiveShell):
     kernel = Any()
     parent_header = Any()
 
-    @default('banner1')
+    @default("banner1")
     def _default_banner1(self):
         return default_banner
 
@@ -455,19 +447,19 @@ class ZMQInteractiveShell(InteractiveShell):
 
     exiter = Instance(ZMQExitAutocall)
 
-    @default('exiter')
+    @default("exiter")
     def _default_exiter(self):
         return ZMQExitAutocall(self)
 
-    @observe('exit_now')
+    @observe("exit_now")
     def _update_exit_now(self, change):
         """stop eventloop when exit_now fires"""
-        if change['new']:
-            if hasattr(self.kernel, 'io_loop'):
+        if change["new"]:
+            if hasattr(self.kernel, "io_loop"):
                 loop = self.kernel.io_loop
                 loop.call_later(0.1, loop.stop)
             if self.kernel.eventloop:
-                exit_hook = getattr(self.kernel.eventloop, 'exit_hook', None)
+                exit_hook = getattr(self.kernel.eventloop, "exit_hook", None)
                 if exit_hook:
                     exit_hook(self.kernel)
 
@@ -477,6 +469,7 @@ class ZMQInteractiveShell(InteractiveShell):
     # interactive input being read; we provide event loop support in ipkernel
     def enable_gui(self, gui):
         from .eventloops import enable_gui as real_enable_gui
+
         try:
             real_enable_gui(gui)
             self.active_eventloop = gui
@@ -487,17 +480,17 @@ class ZMQInteractiveShell(InteractiveShell):
         """Configure the user's environment."""
         env = os.environ
         # These two ensure 'ls' produces nice coloring on BSD-derived systems
-        env['TERM'] = 'xterm-color'
-        env['CLICOLOR'] = '1'
+        env["TERM"] = "xterm-color"
+        env["CLICOLOR"] = "1"
         # Since normal pagers don't work at all (over pexpect we don't have
         # single-key control of the subprocess), try to disable paging in
         # subprocesses as much as possible.
-        env['PAGER'] = 'cat'
-        env['GIT_PAGER'] = 'cat'
+        env["PAGER"] = "cat"
+        env["GIT_PAGER"] = "cat"
 
     def init_hooks(self):
         super().init_hooks()
-        self.set_hook('show_in_pager', page.as_hook(payloadpage.page), 99)
+        self.set_hook("show_in_pager", page.as_hook(payloadpage.page), 99)
 
     def init_data_pub(self):
         """Delay datapub init until request, for deprecation warnings"""
@@ -505,9 +498,12 @@ class ZMQInteractiveShell(InteractiveShell):
 
     @property
     def data_pub(self):
-        if not hasattr(self, '_data_pub'):
-            warnings.warn("InteractiveShell.data_pub is deprecated outside IPython parallel.",
-                DeprecationWarning, stacklevel=2)
+        if not hasattr(self, "_data_pub"):
+            warnings.warn(
+                "InteractiveShell.data_pub is deprecated outside IPython parallel.",
+                DeprecationWarning,
+                stacklevel=2,
+            )
 
             self._data_pub = self.data_pub_class(parent=self)
             self._data_pub.session = self.display_pub.session
@@ -520,9 +516,9 @@ class ZMQInteractiveShell(InteractiveShell):
 
     def ask_exit(self):
         """Engage the exit actions."""
-        self.exit_now = (not self.keepkernel_on_exit)
+        self.exit_now = not self.keepkernel_on_exit
         payload = dict(
-            source='ask_exit',
+            source="ask_exit",
             keepkernel=self.keepkernel_on_exit,
         )
         self.payload_manager.write_payload(payload)
@@ -537,9 +533,9 @@ class ZMQInteractiveShell(InteractiveShell):
         sys.stderr.flush()
 
         exc_content = {
-            'traceback' : stb,
-            'ename' : str(etype.__name__),
-            'evalue' : str(evalue),
+            "traceback": stb,
+            "ename": str(etype.__name__),
+            "evalue": str(evalue),
         }
 
         dh = self.displayhook
@@ -547,7 +543,7 @@ class ZMQInteractiveShell(InteractiveShell):
         # to pick up
         topic = None
         if dh.topic:
-            topic = dh.topic.replace(b'execute_result', b'error')
+            topic = dh.topic.replace(b"execute_result", b"error")
 
         dh.session.send(
             dh.pub_socket,
@@ -565,7 +561,7 @@ class ZMQInteractiveShell(InteractiveShell):
         """Send the specified text to the frontend to be presented at the next
         input cell."""
         payload = dict(
-            source='set_next_input',
+            source="set_next_input",
             text=text,
             replace=replace,
         )
@@ -576,7 +572,7 @@ class ZMQInteractiveShell(InteractiveShell):
         self.parent_header = parent
         self.displayhook.set_parent(parent)
         self.display_pub.set_parent(parent)
-        if hasattr(self, '_data_pub'):
+        if hasattr(self, "_data_pub"):
             self.data_pub.set_parent(parent)
         try:
             sys.stdout.set_parent(parent)
@@ -593,7 +589,7 @@ class ZMQInteractiveShell(InteractiveShell):
     def init_magics(self):
         super().init_magics()
         self.register_magics(KernelMagics)
-        self.magics_manager.register_alias('ed', 'edit')
+        self.magics_manager.register_alias("ed", "edit")
 
     def init_virtualenv(self):
         # Overridden not to do virtualenv detection, because it's probably
@@ -612,7 +608,7 @@ class ZMQInteractiveShell(InteractiveShell):
             not supported.  Should not be a command that expects input
             other than simple text.
         """
-        if cmd.rstrip().endswith('&'):
+        if cmd.rstrip().endswith("&"):
             # this is *far* from a rigorous test
             # We do not support backgrounding processes because we either use
             # pexpect or pipes to read from.  Users can always just call
@@ -625,15 +621,16 @@ class ZMQInteractiveShell(InteractiveShell):
         # Instead, we store the exit_code in user_ns.
         # Also, protect system call from UNC paths on Windows here too
         # as is done in InteractiveShell.system_raw
-        if sys.platform == 'win32':
+        if sys.platform == "win32":
             cmd = self.var_expand(cmd, depth=1)
             from IPython.utils._process_win32 import AvoidUNCPath
+
             with AvoidUNCPath() as path:
                 if path is not None:
-                    cmd = 'pushd %s &&%s' % (path, cmd)
-                self.user_ns['_exit_code'] = system(cmd)
+                    cmd = "pushd %s &&%s" % (path, cmd)
+                self.user_ns["_exit_code"] = system(cmd)
         else:
-            self.user_ns['_exit_code'] = system(self.var_expand(cmd, depth=1))
+            self.user_ns["_exit_code"] = system(self.var_expand(cmd, depth=1))
 
     # Ensure new system_piped implementation is used
     system = system_piped
